static EXTENSIONS: phf::Map<&'static str, &[&str]> =
::phf::Map {
    key: 3213172566270843353,
    disps: ::phf::Slice::Static(&[
        (0, 0),
        (0, 391),
        (0, 57),
        (0, 0),
        (0, 427),
        (0, 0),
        (0, 193),
        (0, 100),
        (0, 46),
        (0, 552),
        (0, 46),
        (0, 2),
        (0, 1),
        (0, 4),
        (0, 170),
        (0, 29),
        (0, 0),
        (0, 14),
        (0, 625),
        (1, 581),
        (0, 14),
        (0, 796),
        (0, 113),
        (0, 67),
        (0, 1),
        (0, 2),
        (0, 391),
        (0, 2),
        (0, 0),
        (0, 56),
        (0, 13),
        (0, 681),
        (0, 3),
        (0, 149),
        (0, 41),
        (0, 8),
        (0, 105),
        (0, 20),
        (0, 18),
        (1, 276),
        (0, 5),
        (0, 3),
        (0, 36),
        (0, 9),
        (3, 28),
        (0, 19),
        (0, 359),
        (0, 2),
        (0, 161),
        (0, 1),
        (0, 40),
        (0, 179),
        (0, 240),
        (0, 307),
        (0, 0),
        (0, 14),
        (0, 189),
        (0, 0),
        (0, 0),
        (0, 8),
        (0, 4),
        (0, 3),
        (0, 0),
        (0, 574),
        (0, 57),
        (1, 1),
        (0, 25),
        (0, 12),
        (0, 30),
        (4, 976),
        (0, 1),
        (0, 0),
        (0, 12),
        (1, 4),
        (0, 2),
        (0, 24),
        (0, 4),
        (0, 120),
        (4, 21),
        (0, 292),
        (0, 5),
        (0, 29),
        (0, 4),
        (0, 71),
        (0, 0),
        (0, 6),
        (0, 28),
        (0, 234),
        (0, 2),
        (0, 8),
        (0, 1053),
        (1, 315),
        (0, 220),
        (0, 889),
        (0, 515),
        (0, 10),
        (0, 606),
        (0, 877),
        (0, 46),
        (0, 26),
        (0, 285),
        (0, 190),
        (0, 270),
        (1, 38),
        (1, 794),
        (0, 10),
        (0, 6),
        (0, 204),
        (0, 4),
        (0, 6),
        (0, 0),
        (0, 2),
        (0, 631),
        (0, 69),
        (4, 103),
        (0, 28),
        (0, 228),
        (0, 465),
        (0, 23),
        (0, 0),
        (0, 1),
        (0, 529),
        (0, 438),
        (0, 98),
        (0, 135),
        (0, 231),
        (0, 2),
        (0, 18),
        (2, 0),
        (0, 619),
        (0, 176),
        (0, 11),
        (0, 129),
        (0, 0),
        (0, 148),
        (0, 2),
        (3, 733),
        (0, 827),
        (0, 44),
        (0, 224),
        (0, 72),
        (0, 7),
        (0, 357),
        (0, 667),
        (0, 627),
        (0, 352),
        (0, 2),
        (0, 416),
        (0, 597),
        (0, 63),
        (0, 0),
        (5, 617),
        (0, 50),
        (8, 209),
        (0, 553),
        (0, 147),
        (0, 11),
        (2, 733),
        (0, 400),
        (0, 819),
        (2, 419),
        (0, 16),
        (0, 2),
        (0, 9),
        (0, 504),
        (0, 11),
        (0, 263),
        (3, 482),
        (0, 59),
        (0, 757),
        (1, 107),
        (0, 2),
        (0, 330),
        (1, 767),
        (0, 30),
        (0, 1),
        (0, 71),
        (0, 22),
        (0, 19),
        (0, 113),
        (0, 33),
        (2, 91),
        (2, 512),
        (1, 4),
        (2, 909),
        (0, 26),
        (0, 745),
        (0, 0),
        (0, 88),
        (4, 640),
        (0, 31),
        (0, 1026),
        (1, 876),
        (0, 862),
        (0, 47),
        (0, 22),
        (0, 254),
        (0, 1080),
        (0, 4),
        (0, 1124),
        (0, 14),
        (7, 100),
        (0, 19),
        (0, 513),
        (0, 369),
        (0, 11),
        (5, 391),
        (0, 269),
        (10, 284),
        (10, 917),
        (0, 93),
        (0, 0),
        (0, 72),
        (1, 1065),
        (4, 351),
        (35, 104),
        (0, 108),
        (3, 210),
        (0, 106),
        (33, 1042),
        (6, 879),
        (1, 557),
        (0, 9),
        (0, 583),
        (1, 47),
        (0, 5),
        (27, 575),
        (9, 227),
        (32, 432),
        (0, 6),
        (0, 268),
    ]),
    entries: ::phf::Slice::Static(&[
        (".udo", &["Csound"]),
        (".cs", &["C#", "Smalltalk"]),
        (".cfm", &["ColdFusion"]),
        (".cproject", &["XML"]),
        (".dockerfile", &["Dockerfile"]),
        (".builder", &["Ruby"]),
        (".cats", &["C"]),
        (".gitconfig", &["Git Config"]),
        (".jsonc", &["JSON with Comments"]),
        (".cr", &["Crystal"]),
        (".rq", &["SPARQL"]),
        (".fcgi", &["PHP", "Shell", "Ruby", "Perl", "Lua", "Python"]),
        (".ipf", &["IGOR Pro"]),
        (".gn", &["GN"]),
        (".vh", &["SystemVerilog"]),
        (".xojo_toolbar", &["Xojo"]),
        (".ivy", &["XML"]),
        (".el", &["Emacs Lisp"]),
        (".phtml", &["HTML+PHP"]),
        (".afm", &["Adobe Font Metrics"]),
        (".ex", &["Elixir"]),
        (".pot", &["Gettext Catalog"]),
        (".xproj", &["XML"]),
        (".rdoc", &["RDoc"]),
        (".ecl", &["ECL", "ECLiPSe"]),
        (".yaml.sed", &["YAML"]),
        (".lbx", &["TeX"]),
        (".myt", &["Myghty"]),
        (".jflex", &["JFlex"]),
        (".pd_lua", &["Lua"]),
        (".chpl", &["Chapel"]),
        (".w", &["CWeb", "OpenEdge ABL"]),
        (".g4", &["ANTLR"]),
        (".tf", &["HCL"]),
        (".hy", &["Hy"]),
        (".gradle", &["Gradle"]),
        (".sexp", &["Common Lisp"]),
        (".tu", &["Turing"]),
        (".ur", &["UrWeb"]),
        (".natvis", &["XML"]),
        (".bsl", &["1C Enterprise"]),
        (".mjml", &["XML"]),
        (".scd", &["SuperCollider"]),
        (".prg", &["xBase"]),
        (".perl", &["Perl"]),
        (".sh-session", &["ShellSession"]),
        (".iss", &["Inno Setup"]),
        (".eh", &["eC"]),
        (".xsjslib", &["JavaScript"]),
        (".json-tmlanguage", &["JSON"]),
        (".hs", &["Haskell"]),
        (".nsi", &["NSIS"]),
        (".wiki", &["MediaWiki"]),
        (".ph", &["Perl"]),
        (".eclass", &["Gentoo Eclass"]),
        (".es", &["Erlang", "JavaScript"]),
        (".xpl", &["XProc"]),
        (".fp", &["GLSL"]),
        (".yacc", &["Yacc"]),
        (".ipynb", &["Jupyter Notebook"]),
        (".rbtbar", &["REALbasic"]),
        (".reb", &["Rebol"]),
        (".plist", &["XML Property List", "OpenStep Property List"]),
        (".txl", &["TXL"]),
        (".tla", &["TLA"]),
        (".pod", &["Pod 6", "Pod"]),
        (".cp", &["Component Pascal", "C++"]),
        (".irclog", &["IRC log"]),
        (".as", &["ActionScript", "AngelScript"]),
        (".zimpl", &["Zimpl"]),
        (".gbr", &["Gerber Image"]),
        (".ccp", &["COBOL"]),
        (".ec", &["eC"]),
        (".zep", &["Zephir"]),
        (".clj", &["Clojure"]),
        (".pasm", &["Parrot Assembly"]),
        (".parrot", &["Parrot"]),
        (".2", &["Roff", "Roff Manpage"]),
        (".cljc", &["Clojure"]),
        (".json5", &["JSON5"]),
        (".txt", &["Text"]),
        (".gbs", &["Gerber Image"]),
        (".upc", &["Unified Parallel C"]),
        (".mq5", &["MQL5"]),
        (".vcl", &["VCL"]),
        (".las", &["Lasso"]),
        (".oz", &["Oz"]),
        (".for", &["Fortran", "Forth", "Formatted"]),
        (".php5", &["PHP"]),
        (".jake", &["JavaScript"]),
        (".c++", &["C++"]),
        (".meta", &["Unity3D Asset"]),
        (".gitignore", &["Ignore List"]),
        (".6", &["Roff", "Roff Manpage"]),
        (".pub", &["Public Key"]),
        (".gsp", &["Groovy Server Pages"]),
        (".jsonnet", &["Jsonnet"]),
        (".bib", &["BibTeX"]),
        (".mirah", &["Mirah"]),
        (".ini", &["INI"]),
        (".ice", &["JSON", "Slice"]),
        (".mustache", &["HTML+Django"]),
        (".wast", &["WebAssembly"]),
        (".bsv", &["Bluespec"]),
        (".asn", &["ASN.1"]),
        (".sublime-keymap", &["JSON with Comments"]),
        (".thy", &["Isabelle"]),
        (".properties", &["Java Properties", "INI"]),
        (".xacro", &["XML"]),
        (".wlua", &["Lua"]),
        (".launch", &["XML"]),
        (".nproj", &["XML"]),
        (".cmake", &["CMake"]),
        (".qll", &["CodeQL"]),
        (".pogo", &["PogoScript"]),
        (".bf", &["HyPhy", "Brainfuck"]),
        (".numpy", &["NumPy"]),
        (".mu", &["mupad"]),
        (".boot", &["Clojure"]),
        (".groovy", &["Groovy"]),
        (".raml", &["RAML"]),
        (".opa", &["Opa"]),
        (".unity", &["Unity3D Asset"]),
        (".mediawiki", &["MediaWiki"]),
        (".j", &["Jasmin", "Objective-J"]),
        (".gd", &["GAP", "GDScript"]),
        (".rbxs", &["Lua"]),
        (".erb.deface", &["HTML+ERB"]),
        (".regexp", &["Regular Expression"]),
        (".sublime-mousemap", &["JSON with Comments"]),
        (".sagews", &["Sage"]),
        (".prefs", &["INI"]),
        (".maxpat", &["Max"]),
        (".a51", &["Assembly"]),
        (".wsgi", &["Python"]),
        (".ipp", &["C++"]),
        (".shproj", &["XML"]),
        (".scxml", &["XML"]),
        (".hpp", &["C++"]),
        (".frx", &["VBA"]),
        (".tmtheme", &["XML Property List"]),
        (".bdy", &["PLSQL"]),
        (".nlogo", &["NetLogo"]),
        (".st", &["Smalltalk", "HTML"]),
        (".1in", &["Roff", "Roff Manpage"]),
        (".cfg", &["INI", "HAProxy"]),
        (".conll", &["CoNLL-U"]),
        (".bmx", &["BlitzMax"]),
        (".lhs", &["Literate Haskell"]),
        (".chs", &["C2hs Haskell"]),
        (".py3", &["Python"]),
        (".bdf", &["Glyph Bitmap Distribution Format"]),
        (".ado", &["Stata"]),
        (".psc1", &["XML"]),
        (".tpl", &["Smarty"]),
        (".tool", &["Shell"]),
        (".mdpolicy", &["XML"]),
        (".js.erb", &["JavaScript+ERB"]),
        (".fea", &["OpenType Feature File"]),
        (".zs", &["ZenScript"]),
        (".4", &["Roff", "Roff Manpage"]),
        (".csh", &["Tcsh"]),
        (".nu", &["Nu"]),
        (".db2", &["SQLPL"]),
        (".flf", &["FIGlet Font"]),
        (".dsp", &["Microsoft Developer Studio Project", "Faust"]),
        (".hc", &["HolyC"]),
        (".rest", &["reStructuredText"]),
        (".kojo", &["Scala"]),
        (".cxx-objdump", &["Cpp-ObjDump"]),
        (".xc", &["XC"]),
        (".spec", &["Ruby", "RPM Spec", "Python"]),
        (".gmx", &["XML"]),
        (".self", &["Self"]),
        (".slim", &["Slim"]),
        (".apl", &["APL"]),
        (".hh", &["C++", "Hack"]),
        (".gtpl", &["Groovy"]),
        (".lsl", &["LSL"]),
        (".blade", &["Blade"]),
        (".regex", &["Regular Expression"]),
        (".fan", &["Fantom"]),
        (".cginc", &["HLSL"]),
        (".8xp.txt", &["TI Program"]),
        (".frg", &["GLSL"]),
        (".sublime-snippet", &["XML"]),
        (".fsi", &["F#"]),
        (".tfvars", &["HCL"]),
        (".1m", &["Roff", "Roff Manpage"]),
        (".csv", &["CSV"]),
        (".gs", &["Genie", "GLSL", "JavaScript", "Gosu"]),
        (".vba", &["Vim script", "VBA"]),
        (".escript", &["Erlang"]),
        (".owl", &["Web Ontology Language"]),
        (".plt", &["Gnuplot"]),
        (".c-objdump", &["C-ObjDump"]),
        (".vsixmanifest", &["XML"]),
        (".xib", &["XML"]),
        (".brd", &["KiCad Legacy Layout", "Eagle"]),
        (".ll", &["LLVM"]),
        (".8xp", &["TI Program"]),
        (".fx", &["FLUX", "HLSL"]),
        (".3", &["Roff", "Roff Manpage"]),
        (".tmpreferences", &["XML Property List"]),
        (".minid", &["MiniD"]),
        (".jinja", &["HTML+Django"]),
        (".xojo_script", &["Xojo"]),
        (".fxh", &["HLSL"]),
        (".gypi", &["Python"]),
        (".pm", &["Raku", "Perl", "X PixMap"]),
        (".ml4", &["OCaml"]),
        (".cake", &["C#", "CoffeeScript"]),
        (".pod6", &["Pod 6"]),
        (".rd", &["R"]),
        (".4dm", &["4D"]),
        (".nim.cfg", &["Nim"]),
        (".reds", &["Red"]),
        (".mxt", &["Max"]),
        (".pp", &["Pascal", "Puppet"]),
        (".pyp", &["Python"]),
        (".mysql", &["SQL"]),
        (".cmd", &["Batchfile"]),
        (".command", &["Shell"]),
        (".jsfl", &["JavaScript"]),
        (".gv", &["Graphviz (DOT)"]),
        (".gbl", &["Gerber Image"]),
        (".webidl", &["WebIDL"]),
        (".handlebars", &["Handlebars"]),
        (".jsonl", &["JSON"]),
        (".nasl", &["NASL"]),
        (".latte", &["Latte"]),
        (".metal", &["Metal"]),
        (".frag", &["GLSL", "JavaScript"]),
        (".ch", &["Charity", "xBase"]),
        (".cjs", &["JavaScript"]),
        (".glade", &["XML"]),
        (".io", &["Io"]),
        (".plot", &["Gnuplot"]),
        (".fth", &["Forth"]),
        (".raw", &["Raw token data"]),
        (".tea", &["Tea"]),
        (".man", &["Roff", "Roff Manpage"]),
        (".grt", &["Groovy"]),
        (".tmac", &["Roff"]),
        (".pyw", &["Python"]),
        (".1x", &["Roff", "Roff Manpage"]),
        (".ditaval", &["XML"]),
        (".pbt", &["PowerBuilder"]),
        (".sjs", &["JavaScript"]),
        (".rl", &["Ragel"]),
        (".au3", &["AutoIt"]),
        (".pov", &["POV-Ray SDL"]),
        (".vtt", &["WebVTT"]),
        (".rbres", &["REALbasic"]),
        (".ma", &["Mathematica"]),
        (".rhtml", &["RHTML"]),
        (".red", &["Red"]),
        (".xpy", &["Python"]),
        (".toc", &["TeX", "World of Warcraft Addon Data"]),
        (".sps", &["Scheme"]),
        (".ndproj", &["XML"]),
        (".cbx", &["TeX"]),
        (".xul", &["XML"]),
        (".pyi", &["Python"]),
        (".scpt", &["AppleScript"]),
        (".hic", &["Clojure"]),
        (".lid", &["Dylan"]),
        (".ebnf", &["EBNF"]),
        (".webmanifest", &["JSON"]),
        (".lol", &["LOLCODE"]),
        (".asy", &["LTspice Symbol", "Asymptote"]),
        (".jinja2", &["HTML+Django"]),
        (".do", &["Stata"]),
        (".axml", &["XML"]),
        (".mkdn", &["Markdown"]),
        (".vim", &["Vim script"]),
        (".html", &["HTML"]),
        (".go", &["Go"]),
        (".cpp-objdump", &["Cpp-ObjDump"]),
        (".xht", &["HTML"]),
        (".re", &["C++", "Reason"]),
        (".riot", &["Riot"]),
        (".zeek", &["Zeek"]),
        (".props", &["XML"]),
        (".bas", &["VBA"]),
        (".cpp", &["C++"]),
        (".druby", &["Mirah"]),
        (".mqh", &["MQL4", "MQL5"]),
        (".mkvi", &["TeX"]),
        (".qasm", &["OpenQASM"]),
        (".sparql", &["SPARQL"]),
        (".rei", &["Reason"]),
        (".liquid", &["Liquid"]),
        (".hb", &["Harbour"]),
        (".aw", &["PHP"]),
        (".shader", &["GLSL", "ShaderLab"]),
        (".decls", &["BlitzBasic"]),
        (".dtx", &["TeX"]),
        (".cps", &["Component Pascal"]),
        (".xojo_code", &["Xojo"]),
        (".asp", &["ASP"]),
        (".p6m", &["Raku"]),
        (".sublime-settings", &["JSON with Comments"]),
        (".lpr", &["Pascal"]),
        (".pl6", &["Raku"]),
        (".3qt", &["Roff", "Roff Manpage"]),
        (".robot", &["RobotFramework"]),
        (".yaml", &["YAML"]),
        (".nawk", &["Awk"]),
        (".iuml", &["PlantUML"]),
        (".mumps", &["M"]),
        (".x10", &["X10"]),
        (".cy", &["Cycript"]),
        (".py", &["Python"]),
        (".mkiv", &["TeX"]),
        (".ino", &["C++"]),
        (".os", &["1C Enterprise"]),
        (".lfe", &["LFE"]),
        (".xrl", &["Erlang"]),
        (".schdoc", &["Altium Designer"]),
        (".rkt", &["Racket"]),
        (".tcc", &["C++"]),
        (".yap", &["Prolog"]),
        (".kicad_mod", &["KiCad Layout"]),
        (".mt", &["Mathematica"]),
        (".rbfrm", &["REALbasic"]),
        (".eb", &["Easybuild"]),
        (".vala", &["Vala"]),
        (".svh", &["SystemVerilog"]),
        (".rno", &["Roff", "RUNOFF"]),
        (".rego", &["Open Policy Agent"]),
        (".eclxml", &["ECL"]),
        (".grxml", &["XML"]),
        (".zil", &["ZIL"]),
        (".xqm", &["XQuery"]),
        (".eam.fs", &["Formatted"]),
        (".factor", &["Factor"]),
        (".cfc", &["ColdFusion CFC"]),
        (".ctp", &["PHP"]),
        (".cmake.in", &["CMake"]),
        (".aux", &["TeX"]),
        (".rmd", &["RMarkdown"]),
        (".ashx", &["ASP"]),
        (".wxl", &["XML"]),
        (".gemspec", &["Ruby"]),
        (".bison", &["Bison"]),
        (".tac", &["Python"]),
        (".http", &["HTTP"]),
        (".jsx", &["JSX"]),
        (".xproc", &["XProc"]),
        (".cwl", &["Common Workflow Language"]),
        (".mkd", &["Markdown"]),
        (".hql", &["HiveQL"]),
        (".cppobjdump", &["Cpp-ObjDump"]),
        (".monkey2", &["Monkey"]),
        (".7", &["Roff", "Roff Manpage"]),
        (".xtend", &["Xtend"]),
        (".tcl", &["Tcl"]),
        (".ssjs", &["JavaScript"]),
        (".textile", &["Textile"]),
        (".com", &["DIGITAL Command Language"]),
        (".c++-objdump", &["Cpp-ObjDump"]),
        (".ml", &["Standard ML", "OCaml"]),
        (".syntax", &["YAML"]),
        (".pan", &["Pan"]),
        (".oxh", &["Ox"]),
        (".me", &["Roff"]),
        (".s", &["Motorola 68K Assembly", "Unix Assembly"]),
        (".tst", &["GAP", "Scilab"]),
        (".gbo", &["Gerber Image"]),
        (".rviz", &["YAML"]),
        (".gko", &["Gerber Image"]),
        (".bbx", &["TeX"]),
        (".ijs", &["J"]),
        (".jisonlex", &["Jison Lex"]),
        (".l", &["Common Lisp", "Roff", "Lex", "PicoLisp"]),
        (".rbbas", &["REALbasic"]),
        (".pkgproj", &["XML"]),
        (".scss", &["SCSS"]),
        (".auk", &["Awk"]),
        (".gtp", &["Gerber Image"]),
        (".plantuml", &["PlantUML"]),
        (".mcfunction", &["mcfunction"]),
        (".vhi", &["VHDL"]),
        (".1", &["Roff", "Roff Manpage"]),
        (".befunge", &["Befunge"]),
        (".fr", &["Frege", "Forth", "Text"]),
        (".ccproj", &["XML"]),
        (".zone", &["DNS Zone"]),
        (".jsb", &["JavaScript"]),
        (".gawk", &["Awk"]),
        (".matah", &["Stata"]),
        (".sss", &["SugarSS"]),
        (".click", &["Click"]),
        (".mm", &["Objective-C++", "XML"]),
        (".depproj", &["XML"]),
        (".pks", &["PLSQL"]),
        (".es6", &["JavaScript"]),
        (".conllu", &["CoNLL-U"]),
        (".outjob", &["Altium Designer"]),
        (".anim", &["Unity3D Asset"]),
        (".styl", &["Stylus"]),
        (".hqf", &["SQF"]),
        (".ne", &["Nearley"]),
        (".sublime_metrics", &["JSON with Comments"]),
        (".5", &["Roff", "Roff Manpage"]),
        (".pic", &["Pic"]),
        (".pony", &["Pony"]),
        (".bones", &["JavaScript"]),
        (".ct", &["XML"]),
        (".pls", &["PLSQL"]),
        (".sass", &["Sass"]),
        (".9", &["Roff", "Roff Manpage"]),
        (".csx", &["C#"]),
        (".zmpl", &["Zimpl"]),
        (".rdf", &["XML"]),
        (".vb", &["Visual Basic .NET"]),
        (".yang", &["YANG"]),
        (".eye", &["Ruby"]),
        (".pwn", &["Pawn"]),
        (".numpyw", &["NumPy"]),
        (".mrc", &["mIRC Script"]),
        (".ik", &["Ioke"]),
        (".gyp", &["Python"]),
        (".rest.txt", &["reStructuredText"]),
        (".sas", &["SAS"]),
        (".axi.erb", &["NetLinx+ERB"]),
        (".jbuilder", &["Ruby"]),
        (".fpp", &["Fortran"]),
        (".builds", &["XML"]),
        (".hhi", &["Hack"]),
        (".asn1", &["ASN.1"]),
        (".b", &["Limbo", "Brainfuck"]),
        (".plb", &["PLSQL"]),
        (".prefab", &["Unity3D Asset"]),
        (".8xk", &["TI Program"]),
        (".xql", &["XQuery"]),
        (".cgi", &["Shell", "Perl", "Python"]),
        (".odin", &["Odin", "Object Data Instance Notation"]),
        (".lean", &["Lean"]),
        (".osm", &["XML"]),
        (".xsp-config", &["XPages"]),
        (".dart", &["Dart"]),
        (".i3", &["Modula-3"]),
        (".gnuplot", &["Gnuplot"]),
        (".rss", &["XML"]),
        (".moon", &["MoonScript"]),
        (".inl", &["C++"]),
        (".fy", &["Fancy"]),
        (".mcr", &["MAXScript"]),
        (".pm6", &["Raku"]),
        (".ox", &["Ox"]),
        (".xspec", &["XML"]),
        (".sublime-macro", &["JSON with Comments"]),
        (".ins", &["TeX"]),
        (".moo", &["Moocode", "Mercury"]),
        (".tfstate", &["JSON"]),
        (".mdown", &["Markdown"]),
        (".gst", &["Gosu"]),
        (".jsm", &["JavaScript"]),
        (".angelscript", &["AngelScript"]),
        (".cls", &["ObjectScript", "TeX", "Apex", "VBA", "OpenEdge ABL"]),
        (".workbook", &["Markdown"]),
        (".csproj", &["XML"]),
        (".tcsh", &["Tcsh"]),
        (".sage", &["Sage"]),
        (".storyboard", &["XML"]),
        (".cocci", &["SmPL"]),
        (".wlt", &["Mathematica"]),
        (".axs", &["NetLinx"]),
        (".csdef", &["XML"]),
        (".njs", &["JavaScript"]),
        (".podsl", &["Common Lisp"]),
        (".workflow", &["XML", "HCL"]),
        (".sty", &["TeX"]),
        (".f95", &["Fortran"]),
        (".flux", &["FLUX"]),
        (".vhf", &["VHDL"]),
        (".nuspec", &["XML"]),
        (".rst", &["reStructuredText"]),
        (".m4", &["M4Sugar", "M4"]),
        (".mkdown", &["Markdown"]),
        (".mo", &["Modelica"]),
        (".nr", &["Roff"]),
        (".texi", &["Texinfo"]),
        (".vue", &["Vue"]),
        (".nim", &["Nim"]),
        (".proto", &["Protocol Buffer"]),
        (".cfml", &["ColdFusion"]),
        (".icl", &["Clean"]),
        (".rbmnu", &["REALbasic"]),
        (".mms", &["Module Management System"]),
        (".lektorproject", &["INI"]),
        (".hbs", &["Handlebars"]),
        (".pprx", &["REXX"]),
        (".pri", &["QMake"]),
        (".rsc", &["Rascal"]),
        (".xojo_report", &["Xojo"]),
        (".p8", &["Lua"]),
        (".rbx", &["Ruby"]),
        (".mako", &["Mako"]),
        (".pascal", &["Pascal"]),
        (".xojo_menu", &["Xojo"]),
        (".asm", &["Motorola 68K Assembly", "Assembly"]),
        (".zap", &["ZAP"]),
        (".fsh", &["GLSL"]),
        (".yasnippet", &["YASnippet"]),
        (".ck", &["ChucK"]),
        (".hlsli", &["HLSL"]),
        (".wxs", &["XML"]),
        (".adml", &["XML"]),
        (".yy", &["Yacc", "JSON"]),
        (".gi", &["GAP"]),
        (".bats", &["Shell"]),
        (".org", &["Org"]),
        (".libsonnet", &["Jsonnet"]),
        (".mat", &["Unity3D Asset"]),
        (".sp", &["SourcePawn"]),
        (".vho", &["VHDL"]),
        (".cxx", &["C++"]),
        ("._ls", &["LiveScript"]),
        (".php3", &["PHP"]),
        (".clp", &["CLIPS"]),
        (".p6", &["Raku"]),
        (".xml.dist", &["XML"]),
        (".aug", &["Augeas"]),
        (".cc", &["C++"]),
        (".dot", &["Graphviz (DOT)"]),
        (".lgt", &["Logtalk"]),
        (".ily", &["LilyPond"]),
        (".rsx", &["R"]),
        (".clixml", &["XML"]),
        (".pike", &["Pike"]),
        (".fsx", &["F#"]),
        (".pep", &["Pep8"]),
        (".axi", &["NetLinx"]),
        (".rst.txt", &["reStructuredText"]),
        (".rsh", &["RenderScript"]),
        (".xmi", &["XML"]),
        (".sv", &["SystemVerilog"]),
        (".tesc", &["GLSL"]),
        (".lagda", &["Literate Agda"]),
        (".bash", &["Shell"]),
        (".tfstate.backup", &["JSON"]),
        (".t", &["Raku", "Turing", "Terra", "Perl"]),
        (".tpb", &["PLSQL"]),
        (".ampl", &["AMPL"]),
        (".wdl", &["wdl"]),
        (".nf", &["Nextflow"]),
        (".frm", &["VBA"]),
        (".vark", &["Gosu"]),
        (".resx", &["XML"]),
        (".md", &["GCC Machine Description", "Markdown"]),
        (".arc", &["Arc"]),
        (".roff", &["Roff"]),
        (".rebol", &["Rebol"]),
        (".sru", &["PowerBuilder"]),
        (".xml", &["XML"]),
        (".xm", &["Logos"]),
        (".opencl", &["OpenCL"]),
        (".lasso9", &["Lasso"]),
        (".ooc", &["ooc"]),
        (".xquery", &["XQuery"]),
        (".gaml", &["GAML"]),
        (".smk", &["Python"]),
        (".wat", &["WebAssembly"]),
        (".yara", &["YARA"]),
        (".glslv", &["GLSL"]),
        (".xlf", &["XML"]),
        (".ecr", &["HTML+ECR"]),
        (".pd", &["Pure Data"]),
        (".sj", &["Objective-J"]),
        (".sublime-completions", &["JSON with Comments"]),
        (".gltf", &["JSON"]),
        (".lasso8", &["Lasso"]),
        (".fst", &["F*"]),
        (".sfd", &["Spline Font Database"]),
        (".emacs", &["Emacs Lisp"]),
        (".json", &["JSON"]),
        (".dircolors", &["dircolors"]),
        (".tl", &["Type Language"]),
        (".nimrod", &["Nim"]),
        (".rs.in", &["Rust"]),
        (".puml", &["PlantUML"]),
        (".mq4", &["MQL4"]),
        (".php", &["PHP", "Hack"]),
        (".ahkl", &["AutoHotkey"]),
        (".ms", &["MAXScript", "Roff", "Unix Assembly"]),
        (".epsi", &["PostScript"]),
        (".htm", &["HTML"]),
        (".nsh", &["NSIS"]),
        (".bal", &["Ballerina"]),
        (".fun", &["Standard ML"]),
        (".mkfile", &["Makefile"]),
        (".kicad_pcb", &["KiCad Layout"]),
        (".marko", &["Marko"]),
        (".cirru", &["Cirru"]),
        (".ps1xml", &["XML"]),
        (".pb", &["PureBasic"]),
        (".di", &["D"]),
        (".dll.config", &["XML"]),
        (".yyp", &["JSON"]),
        (".srw", &["PowerBuilder"]),
        (".scrbl", &["Racket"]),
        (".nbp", &["Mathematica"]),
        (".emberscript", &["EmberScript"]),
        (".psd1", &["PowerShell"]),
        (".erb", &["HTML+ERB"]),
        (".ltx", &["TeX"]),
        (".qml", &["QML"]),
        (".vhdl", &["VHDL"]),
        (".ol", &["Jolie"]),
        (".gni", &["GN"]),
        (".maxproj", &["Max"]),
        (".tm", &["Tcl"]),
        (".vssettings", &["XML"]),
        (".monkey", &["Monkey"]),
        (".omgrofl", &["Omgrofl"]),
        (".cdf", &["Mathematica"]),
        (".diff", &["Diff"]),
        (".nasm", &["Assembly"]),
        (".app.src", &["Erlang"]),
        (".srt", &["SubRip Text", "SRecode Template"]),
        (".nims", &["Nim"]),
        (".bzl", &["Starlark"]),
        (".ejs", &["EJS"]),
        (".snippet", &["Vim Snippet"]),
        (".dita", &["XML"]),
        (".nimble", &["Nim"]),
        (".tmsnippet", &["XML Property List"]),
        (".fish", &["fish"]),
        (".pas", &["Pascal"]),
        (".gsx", &["Gosu"]),
        (".gts", &["Gerber Image"]),
        (".hats", &["ATS"]),
        (".mir", &["YAML"]),
        (".darcspatch", &["Darcs Patch"]),
        (".kid", &["Genshi"]),
        (".tex", &["TeX"]),
        (".erl", &["Erlang"]),
        (".glf", &["Glyph"]),
        (".pro", &["IDL", "Prolog", "QMake", "Proguard", "INI"]),
        (".mk", &["Makefile"]),
        (".mli", &["OCaml"]),
        (".cobol", &["COBOL"]),
        (".mata", &["Stata"]),
        (".glslf", &["GLSL"]),
        (".xsjs", &["JavaScript"]),
        (".xhtml", &["HTML"]),
        (".zsh", &["Shell"]),
        (".sed", &["sed"]),
        (".desktop", &["desktop"]),
        (".html.hl", &["HTML"]),
        (".rs", &["Rust", "RenderScript"]),
        (".scm", &["Scheme"]),
        (".pcbdoc", &["Altium Designer"]),
        (".spc", &["PLSQL"]),
        (".eex", &["HTML+EEX"]),
        (".php4", &["PHP"]),
        (".spin", &["Propeller Spin"]),
        (".f", &["Fortran", "Filebench WML", "Forth"]),
        (".cnc", &["G-code"]),
        (".mcmeta", &["JSON"]),
        (".smt", &["SMT"]),
        (".ninja", &["Ninja"]),
        (".matlab", &["MATLAB"]),
        (".hxx", &["C++"]),
        (".odd", &["XML"]),
        (".maxhelp", &["Max"]),
        (".dyl", &["Dylan"]),
        (".eps", &["PostScript"]),
        (".nit", &["Nit"]),
        (".pyt", &["Python"]),
        (".rg", &["Rouge"]),
        (".filters", &["XML"]),
        (".cpy", &["COBOL"]),
        (".lisp", &["Common Lisp", "NewLisp"]),
        (".rake", &["Ruby"]),
        (".pyde", &["Python"]),
        (".dfm", &["Pascal"]),
        (".cl", &["Common Lisp", "Cool", "OpenCL"]),
        (".texinfo", &["Texinfo"]),
        (".eliom", &["OCaml"]),
        (".js", &["JavaScript"]),
        (".hxsl", &["Haxe"]),
        (".no", &["Text"]),
        (".ncl", &["NCL", "XML", "Text"]),
        (".hack", &["Hack"]),
        (".lua", &["Lua"]),
        (".reg", &["Windows Registry Entries"]),
        (".topojson", &["JSON"]),
        (".i7x", &["Inform 7"]),
        (".dcl", &["Clean"]),
        (".applescript", &["AppleScript"]),
        (".d", &["Makefile", "DTrace", "D"]),
        (".admx", &["XML"]),
        (".webapp", &["JSON"]),
        (".em", &["EmberScript"]),
        (".gco", &["G-code"]),
        (".jsproj", &["XML"]),
        (".3in", &["Roff", "Roff Manpage"]),
        (".psgi", &["Perl"]),
        (".yml", &["YAML"]),
        (".jl", &["Julia"]),
        (".gf", &["Grammatical Framework"]),
        (".gms", &["GAMS"]),
        (".frt", &["Forth"]),
        (".6pm", &["Raku"]),
        (".cbl", &["COBOL"]),
        (".tpp", &["C++"]),
        (".kts", &["Kotlin"]),
        (".r2", &["Rebol"]),
        (".view.lkml", &["LookML"]),
        (".sats", &["ATS"]),
        (".sld", &["Scheme"]),
        (".f03", &["Fortran"]),
        (".avsc", &["JSON"]),
        (".trg", &["PLSQL"]),
        (".xsd", &["XML"]),
        (".muse", &["Muse"]),
        (".m3", &["Modula-3"]),
        (".udf", &["SQL"]),
        (".logtalk", &["Logtalk"]),
        (".xi", &["Logos"]),
        (".mud", &["ZIL"]),
        (".mdwn", &["Markdown"]),
        (".kicad_wks", &["KiCad Layout"]),
        (".jelly", &["XML"]),
        (".prc", &["PLSQL", "SQL"]),
        (".pde", &["Processing"]),
        (".vhd", &["VHDL"]),
        (".pgsql", &["PLpgSQL"]),
        (".jade", &["Pug"]),
        (".n", &["Roff", "Nemerle"]),
        (".apib", &["API Blueprint"]),
        (".nl", &["NewLisp", "NL"]),
        (".hcl", &["HCL"]),
        (".adb", &["Ada"]),
        (".dpr", &["Pascal"]),
        (".oxo", &["Ox"]),
        (".urdf", &["XML"]),
        (".dlm", &["IDL"]),
        (".xaml", &["XML"]),
        (".prjpcb", &["Altium Designer"]),
        (".sml", &["Standard ML"]),
        (".cabal", &["Cabal Config"]),
        (".hxml", &["HXML"]),
        (".aj", &["AspectJ"]),
        (".ascx", &["ASP"]),
        (".hsc", &["Haskell"]),
        (".p6l", &["Raku"]),
        (".po", &["Gettext Catalog"]),
        (".gql", &["GraphQL"]),
        (".razor", &["HTML+Razor"]),
        (".asset", &["Unity3D Asset"]),
        (".hs-boot", &["Haskell"]),
        (".gpb", &["Gerber Image"]),
        (".mod", &["Modula-2", "Linux Kernel Module", "AMPL", "XML"]),
        (".mao", &["Mako"]),
        (".rex", &["REXX"]),
        (".jsp", &["Java Server Pages"]),
        (".orc", &["Csound"]),
        (".ktm", &["Kotlin"]),
        (".mlir", &["MLIR"]),
        (".xliff", &["XML"]),
        (".model.lkml", &["LookML"]),
        (".feature", &["Gherkin"]),
        (".vbhtml", &["Visual Basic .NET"]),
        (".ccxml", &["XML"]),
        (".plsql", &["PLSQL"]),
        (".geo", &["GLSL"]),
        (".h", &["Objective-C", "C", "C++"]),
        (".gvy", &["Groovy"]),
        (".proj", &["XML"]),
        (".ceylon", &["Ceylon"]),
        (".ant", &["XML"]),
        (".cscfg", &["XML"]),
        (".dhall", &["Dhall"]),
        (".cw", &["Redcode"]),
        (".nqp", &["Raku"]),
        (".elm", &["Elm"]),
        (".c++objdump", &["Cpp-ObjDump"]),
        (".bat", &["Batchfile"]),
        (".grace", &["Grace"]),
        (".vcxproj", &["XML"]),
        (".eml", &["EML"]),
        (".mawk", &["Awk"]),
        (".djs", &["Dogescript"]),
        (".ui", &["XML"]),
        (".toml", &["TOML"]),
        (".agda", &["Agda"]),
        (".f08", &["Fortran"]),
        (".rktl", &["Racket"]),
        (".3pm", &["Roff", "Roff Manpage"]),
        (".cl2", &["Clojure"]),
        (".shen", &["Shen"]),
        (".har", &["JSON"]),
        (".tps", &["PLSQL"]),
        (".emacs.desktop", &["Emacs Lisp"]),
        (".xq", &["XQuery"]),
        (".vxml", &["XML"]),
        (".ksh", &["Shell"]),
        (".sfproj", &["XML"]),
        (".iced", &["CoffeeScript"]),
        (".ps1", &["PowerShell"]),
        (".ux", &["XML"]),
        (".nginxconf", &["Nginx"]),
        (".qbs", &["QML"]),
        (".lvproj", &["LabVIEW"]),
        (".snip", &["Vim Snippet"]),
        (".f77", &["Fortran"]),
        (".sthlp", &["Stata"]),
        (".fs", &["GLSL", "Forth", "Filterscript", "F#"]),
        (".dm", &["DM"]),
        (".rb", &["Ruby"]),
        (".duby", &["Mirah"]),
        (".rockspec", &["Lua"]),
        (".xqy", &["XQuery"]),
        (".ni", &["Inform 7"]),
        (".clw", &["Clarion"]),
        (".sublime-build", &["JSON with Comments"]),
        (".lex", &["Lex"]),
        (".ruby", &["Ruby"]),
        (".intr", &["Dylan"]),
        (".svelte", &["Svelte"]),
        (".awk", &["Awk"]),
        (".vmb", &["Vim script"]),
        (".xpm", &["X PixMap"]),
        (".fnc", &["PLSQL"]),
        (".svg", &["SVG"]),
        (".god", &["Ruby"]),
        (".lmi", &["Python"]),
        (".sublime-theme", &["JSON with Comments"]),
        (".aspx", &["ASP"]),
        (".idr", &["Idris"]),
        (".pir", &["Parrot Internal Representation"]),
        (".axd", &["ASP"]),
        (".cob", &["COBOL"]),
        (".p4", &["P4"]),
        (".mtl", &["Wavefront Material"]),
        (".podspec", &["Ruby"]),
        (".4th", &["Forth"]),
        (".hx", &["Haxe"]),
        (".8", &["Roff", "Roff Manpage"]),
        (".sls", &["SaltStack", "Scheme"]),
        (".sh.in", &["Shell"]),
        (".watchr", &["Ruby"]),
        (".edn", &["edn"]),
        (".8xk.txt", &["TI Program"]),
        (".mspec", &["Ruby"]),
        (".pbi", &["PureBasic"]),
        (".fsproj", &["XML"]),
        (".xsl", &["XSLT"]),
        (".vshader", &["GLSL"]),
        (".dylan", &["Dylan"]),
        (".lasso", &["Lasso"]),
        (".3m", &["Roff", "Roff Manpage"]),
        (".nse", &["Lua"]),
        (".fancypack", &["Fancy"]),
        (".kml", &["XML"]),
        (".pytb", &["Python traceback"]),
        (".ihlp", &["Stata"]),
        (".3x", &["Roff", "Roff Manpage"]),
        (".dotsettings", &["XML"]),
        (".xslt", &["XSLT"]),
        (".cuh", &["Cuda"]),
        (".markdown", &["Markdown"]),
        (".prolog", &["Prolog"]),
        (".g", &["G-code", "GAP"]),
        (".ring", &["Ring"]),
        (".r", &["R", "Rebol"]),
        (".rnh", &["RUNOFF"]),
        ("._coffee", &["CoffeeScript"]),
        (".vhs", &["VHDL"]),
        (".fxml", &["XML"]),
        (".wixproj", &["XML"]),
        (".dyalog", &["APL"]),
        (".uc", &["UnrealScript"]),
        (".hrl", &["Erlang"]),
        (".gap", &["GAP"]),
        (".dof", &["INI"]),
        (".postcss", &["PostCSS"]),
        (".als", &["Alloy"]),
        (".hlean", &["Lean"]),
        (".cljs", &["Clojure"]),
        (".mbox", &["EML"]),
        (".purs", &["PureScript"]),
        (".ddl", &["PLSQL", "SQL"]),
        (".nut", &["Squirrel"]),
        (".csl", &["XML"]),
        (".less", &["Less"]),
        (".graphqls", &["GraphQL"]),
        (".sqf", &["SQF"]),
        (".v", &["V", "Coq", "Verilog"]),
        (".mask", &["Unity3D Asset", "Mask"]),
        (".rexx", &["REXX"]),
        (".apacheconf", &["ApacheConf"]),
        (".kit", &["Kit"]),
        (".blade.php", &["Blade"]),
        (".doh", &["Stata"]),
        (".ps", &["PostScript"]),
        (".sql", &["TSQL", "PLSQL", "SQL", "PLpgSQL", "SQLPL"]),
        (".txi", &["Texinfo"]),
        (".sma", &["Pawn"]),
        (".wisp", &["wisp"]),
        (".pkb", &["PLSQL"]),
        (".mmk", &["Module Management System"]),
        (".stan", &["Stan"]),
        (".psc", &["Papyrus"]),
        (".ada", &["Ada"]),
        (".viw", &["SQL"]),
        (".ts", &["XML", "TypeScript"]),
        (".objdump", &["ObjDump"]),
        (".mjs", &["JavaScript"]),
        (".vhw", &["VHDL"]),
        (".flex", &["JFlex"]),
        (".jsonld", &["JSONLD"]),
        (".capnp", &["Cap\'n Proto"]),
        (".tml", &["XML"]),
        (".forth", &["Forth"]),
        (".lsp", &["Common Lisp", "NewLisp"]),
        (".boo", &["Boo"]),
        (".sco", &["Csound Score"]),
        (".inc", &["Motorola 68K Assembly", "SourcePawn", "HTML", "PHP", "NASL", "C++", "Assembly", "SQL", "Pawn", "Pascal", "POV-Ray SDL"]),
        (".volt", &["Volt"]),
        (".yrl", &["Erlang"]),
        (".asc", &["AsciiDoc", "Public Key", "AGS Script"]),
        (".targets", &["XML"]),
        (".vw", &["PLSQL"]),
        (".geom", &["GLSL"]),
        (".m", &["Limbo", "M", "MUF", "Objective-C", "MATLAB", "Mathematica", "Mercury"]),
        (".yaml-tmlanguage", &["YAML"]),
        (".ahk", &["AutoHotkey"]),
        (".lslp", &["LSL"]),
        (".make", &["Makefile"]),
        (".x68", &["Motorola 68K Assembly"]),
        (".weechatlog", &["IRC log"]),
        (".sublime-project", &["JSON with Comments"]),
        (".gnu", &["Gnuplot"]),
        (".tab", &["SQL"]),
        (".y", &["Yacc"]),
        (".opal", &["Opal"]),
        (".gml", &["Game Maker Language", "XML", "Gerber Image", "Graph Modeling Language"]),
        (".njk", &["HTML+Django"]),
        (".yar", &["YARA"]),
        (".6pl", &["Raku"]),
        (".dwl", &["DataWeave"]),
        (".idc", &["C"]),
        (".gdb", &["GDB"]),
        (".vrx", &["GLSL"]),
        (".coffee", &["CoffeeScript"]),
        (".ditamap", &["XML"]),
        (".bro", &["Zeek"]),
        (".edc", &["Edje Data Collection"]),
        (".ston", &["STON"]),
        (".adp", &["Tcl"]),
        (".gp", &["Gnuplot"]),
        (".c", &["C"]),
        (".hlsl", &["HLSL"]),
        (".sc", &["SuperCollider", "Scala"]),
        (".wxi", &["XML"]),
        (".lookml", &["LookML"]),
        (".al", &["Perl"]),
        (".wsf", &["XML"]),
        (".rbi", &["Ruby"]),
        (".coq", &["Coq"]),
        (".sce", &["Scilab"]),
        (".nc", &["nesC"]),
        (".pac", &["JavaScript"]),
        (".desktop.in", &["desktop"]),
        (".pluginspec", &["Ruby", "XML"]),
        (".dae", &["COLLADA"]),
        (".vsh", &["GLSL"]),
        (".phps", &["PHP"]),
        (".vbs", &["VBScript"]),
        (".lidr", &["Idris"]),
        (".thor", &["Ruby"]),
        (".asmx", &["ASP"]),
        (".cljscm", &["Clojure"]),
        (".sl", &["Slash"]),
        (".pyx", &["Cython"]),
        (".vbproj", &["XML"]),
        (".muf", &["MUF"]),
        (".ss", &["Scheme"]),
        (".sublime-menu", &["JSON with Comments"]),
        (".cljx", &["Clojure"]),
        (".zpl", &["Zimpl"]),
        (".ash", &["AGS Script"]),
        (".iml", &["XML"]),
        (".mdoc", &["Roff", "Roff Manpage"]),
        (".swift", &["Swift"]),
        (".pat", &["Max"]),
        (".mg", &["Modula-3"]),
        (".jscad", &["JavaScript"]),
        (".gshader", &["GLSL"]),
        (".phpt", &["PHP"]),
        (".brs", &["Brightscript"]),
        (".bb", &["BlitzBasic", "BitBake"]),
        (".nix", &["Nix"]),
        (".sublime-workspace", &["JSON with Comments"]),
        (".3p", &["Roff", "Roff Manpage"]),
        (".ads", &["Ada"]),
        (".golo", &["Golo"]),
        (".cql", &["SQL"]),
        (".cu", &["Cuda"]),
        (".java", &["Java"]),
        (".pck", &["PLSQL"]),
        (".fshader", &["GLSL"]),
        (".css", &["CSS"]),
        (".gcode", &["G-code"]),
        (".rbuild", &["Ruby"]),
        (".scala", &["Scala"]),
        (".axs.erb", &["NetLinx+ERB"]),
        (".sublime_session", &["JSON with Comments"]),
        (".gdbinit", &["GDB"]),
        (".p", &["Gnuplot", "OpenEdge ABL"]),
        (".chem", &["Pic"]),
        (".mll", &["OCaml"]),
        (".q", &["q", "HiveQL"]),
        (".x", &["Logos", "RPC", "Linker Script", "DirectX 3D File"]),
        (".cshtml", &["HTML+Razor"]),
        (".pt", &["XML"]),
        (".dats", &["ATS"]),
        (".numsc", &["NumPy"]),
        (".ny", &["Common Lisp"]),
        (".asd", &["Common Lisp"]),
        (".nearley", &["Nearley"]),
        (".sublime-commands", &["JSON with Comments"]),
        (".haml.deface", &["Haml"]),
        (".f90", &["Fortran"]),
        (".scad", &["OpenSCAD"]),
        (".xojo_window", &["Xojo"]),
        (".graphql", &["GraphQL"]),
        (".x3d", &["XML"]),
        (".rpy", &["Ren\'Py", "Python"]),
        (".r3", &["Rebol"]),
        (".jq", &["JSONiq"]),
        (".tsx", &["TSX", "XML"]),
        (".vstemplate", &["XML"]),
        (".plx", &["Perl"]),
        (".zcml", &["XML"]),
        (".i", &["SWIG", "Motorola 68K Assembly", "Assembly"]),
        (".gtl", &["Gerber Image"]),
        (".mly", &["OCaml"]),
        (".ronn", &["Markdown"]),
        (".jss", &["JavaScript"]),
        (".veo", &["Verilog"]),
        (".cljs.hl", &["Clojure"]),
        (".agc", &["Apollo Guidance Computer"]),
        (".obj", &["Wavefront Object"]),
        (".ig", &["Modula-3"]),
        (".xbm", &["X BitMap"]),
        (".smt2", &["SMT"]),
        (".haml", &["Haml"]),
        (".ly", &["LilyPond"]),
        (".abnf", &["ABNF"]),
        (".ls", &["LoomScript", "LiveScript"]),
        (".snippets", &["Vim Snippet"]),
        (".sbt", &["Scala"]),
        (".h++", &["C++"]),
        (".krl", &["KRL"]),
        (".litcoffee", &["Literate CoffeeScript"]),
        (".exs", &["Elixir"]),
        (".vhost", &["Nginx", "ApacheConf"]),
        (".adoc", &["AsciiDoc"]),
        (".tmlanguage", &["XML Property List"]),
        (".xsp.metadata", &["XPages"]),
        (".asax", &["ASP"]),
        (".mtml", &["MTML"]),
        (".pug", &["Pug"]),
        (".pfa", &["PostScript"]),
        (".scaml", &["Scaml"]),
        (".ftl", &["FreeMarker"]),
        (".pxd", &["Cython"]),
        (".rbuistate", &["REALbasic"]),
        (".wsdl", &["XML"]),
        (".psm1", &["PowerShell"]),
        (".sig", &["Standard ML"]),
        (".sci", &["Scilab"]),
        (".asciidoc", &["AsciiDoc"]),
        (".wl", &["Mathematica"]),
        (".iol", &["Jolie"]),
        (".xzap", &["ZAP"]),
        (".cson", &["CSON"]),
        (".twig", &["Twig"]),
        (".csd", &["Csound Document"]),
        (".reek", &["YAML"]),
        (".dpatch", &["Darcs Patch"]),
        (".nb", &["Text", "Mathematica"]),
        (".pxi", &["Cython"]),
        (".patch", &["Diff"]),
        (".urs", &["UrWeb"]),
        (".mathematica", &["Mathematica"]),
        (".ttl", &["Turtle"]),
        (".pkl", &["Pickle"]),
        (".rtf", &["Rich Text Format"]),
        (".pig", &["PigLatin"]),
        (".gbp", &["Gerber Image"]),
        (".epj", &["Ecere Projects"]),
        (".d-objdump", &["D-ObjDump"]),
        (".uno", &["Uno"]),
        (".oxygene", &["Oxygene"]),
        (".ru", &["Ruby"]),
        (".mxml", &["XML"]),
        (".tmcommand", &["XML Property List"]),
        (".rbw", &["Ruby"]),
        (".e", &["E", "Eiffel"]),
        (".glsl", &["GLSL"]),
        (".ebuild", &["Gentoo Ebuild"]),
        (".abap", &["ABAP"]),
        (".pl", &["Raku", "Prolog", "Perl"]),
        (".arpa", &["DNS Zone"]),
        (".pmod", &["Pike"]),
        (".prw", &["xBase"]),
        (".ld", &["Linker Script"]),
        ("._js", &["JavaScript"]),
        (".cjsx", &["CoffeeScript"]),
        (".gto", &["Gerber Image"]),
        (".gpt", &["Gerber Image"]),
        (".srdf", &["XML"]),
        (".yml.mysql", &["YAML"]),
        (".nanorc", &["nanorc"]),
        (".wlk", &["Wollok"]),
        (".mak", &["Makefile"]),
        (".ql", &["CodeQL"]),
        (".thrift", &["Thrift"]),
        (".vapi", &["Vala"]),
        (".sublime-syntax", &["YAML"]),
        (".eliomi", &["OCaml"]),
        (".jison", &["Jison"]),
        (".geojson", &["JSON"]),
        (".mdx", &["Markdown"]),
        (".creole", &["Creole"]),
        (".bibtex", &["BibTeX"]),
        (".rabl", &["Ruby"]),
        (".tmux", &["Shell"]),
        (".tese", &["GLSL"]),
        (".mkii", &["TeX"]),
        (".lds", &["Linker Script"]),
        (".vert", &["GLSL"]),
        (".sttheme", &["XML Property List"]),
        (".eq", &["EQ"]),
        (".smali", &["Smali"]),
        (".vht", &["VHDL"]),
        (".sch", &["KiCad Schematic", "Scheme", "Eagle", "XML"]),
        (".sh", &["Shell"]),
        (".kt", &["Kotlin"]),
        (".prisma", &["Prisma"]),
        (".rktd", &["Racket"]),
        (".mss", &["CartoCSS"]),
        (".xs", &["XS"]),
        (".soy", &["Closure Templates"]),
        (".pcss", &["PostCSS"]),
        (".zig", &["Zig"]),
        (".sra", &["PowerBuilder"]),
    ]),
};

